<?php

/**
 * @file
 * Contains \Drupal\simpleconnect\Controller\SimpleConnectController.
 */

namespace Drupal\simpleconnect\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\DependencyInjection\ContainerInterface;
use \Drupal\Core\Access\CsrfRequestHeaderAccessCheck;


/**
 * Controller routines for simpleconnect routes.
 */
class SimpleConnectController extends ControllerBase {

  /**
   * Callback for `simpleconnect/token` API method.
   */
  public function token( Request $request ) {
    $token=\Drupal::csrfToken()->get(CsrfRequestHeaderAccessCheck::TOKEN_KEY);
    $response =  new Response( $token,200 );
    $response->headers->set('Content-Type', 'text/plain');
  return $response;
  }

   /**
   * Callback for `simpleconnect/es5js`
   * 
   * @return string
   *  Returns ES5(also know as ECMAScript 2009) compatible Javascript
   */
  public function es5js( Request $request ) {
    $module_handler = \Drupal::service('module_handler');
    $module_path = $module_handler->getModule('simpleconnect')->getPath();
    $js=file_get_contents ($module_path.'/js/simple-connect-es5.js');
    $response = new Response($js, 200, array());
    $response->headers->set('Content-Type', 'text/javascript;charset=UTF-8');
    return $response;
  }

  /**
   * Callback for `simpleconnect/es6js
   * 
   * @return string
   *  Returns ES6(also know as ECMAScript 2015) compatible Javascript
   */
  public function es6js( Request $request ) {
    $module_handler = \Drupal::service('module_handler');
    $module_path = $module_handler->getModule('simpleconnect')->getPath();
    $js=file_get_contents ($module_path.'/js/simple-connect-es6.js');
    $response = new Response($js, 200, array());
    $response->headers->set('Content-Type', 'text/javascript;charset=UTF-8');
    return $response;
  }

}
