<?php
  /**
  * Provides a REST  resource for Connect Endpont.
  * Returns the current connected or the anonymous user.
  *
  */

namespace Drupal\simpleconnect\Plugin\rest\resource;
  use Drupal\Core\Session\AccountProxyInterface;
  use Drupal\node\Entity\Node;
  use Drupal\rest\ModifiedResourceResponse;
  use Drupal\rest\Plugin\ResourceBase;
  use Drupal\rest\ResourceResponse;
  use Psr\Log\LoggerInterface;
  use Symfony\Component\DependencyInjection\ContainerInterface;
  use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
  use \Drupal\Core\Url;



/**
* Provides a resource to get view modes by entity and bundle.
*
* @RestResource(
*   id = "connect",
*   label = @Translation("Connect"),
*   serialization_class = "",
*   uri_paths = {
*     "https://www.drupal.org/link-relations/create" = "/rest/simpleconnect/connect"
*   }
* )
*/
class SimpleConnectConnectResource extends ResourceBase {
 
  /**
  * A current user instance.
  *
  * @var \Drupal\Core\Session\AccountProxyInterface
  */
  protected $currentUser;
 
  /**
  * Constructs a new SimpleConnectResource object.
  *
  * @param array $configuration
  *   A configuration array containing information about the plugin instance.
  * @param string $plugin_id
  *   The plugin_id for the plugin instance.
  * @param mixed $plugin_definition
  *   The plugin implementation definition.
  * @param array $serializer_formats
  *   The available serialization formats.
  * @param \Psr\Log\LoggerInterface $logger
  *   A logger instance.
  * @param \Drupal\Core\Session\AccountProxyInterface $current_user
  *   A current user instance.
  */
  public function __construct(
      array $configuration,
      $plugin_id,
      $plugin_definition,
      array $serializer_formats,
      LoggerInterface $logger,
  AccountProxyInterface $current_user) {
        parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);
        $this->currentUser = $current_user;
  }
 
  /**
  * {@inheritdoc}
  * 
  */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
      return new static(
          $configuration,
          $plugin_id,
          $plugin_definition,
          $container->getParameter('serializer.formats'),
          $container->get('logger.factory')->get('simpleconnect'),
          $container->get('current_user')
        );
      }
 
 /**
 * Responds to POST requests.
 *
 *
 * @return object uid|int username|string roles|array
 *
 * @throws \Symfony\Component\HttpKernel\Exception\HttpException
 *   Throws exception expected.
 */
  public function post($node_data) {
        // You must to implement the logic of your REST Resource here.
        // Use current user after pass authentication to validate access.
        if (!$this->currentUser->hasPermission('access content')) {
          throw new AccessDeniedHttpException();
        }
     
     $current_user = $this->currentUser;
     $roles = $current_user->getRoles();
     $uid=$current_user->id();
     $name=$current_user->getUsername();
     if($uid==0)$name=t("Anonymous");

     $message = [
              'uid' => $uid,
              'username' => $name,
              'roles' => $roles,
            ];

    //do not cache 
     $build = array(
        '#cache' => array(
        'max-age' => 0,
        ),
      );
  return (new ResourceResponse($message))->addCacheableDependency($build);
  }
       

}