<?php
 /**
 * Provides a REST  resource for SimpleConnect Login Endpont.
 * Returns the logged in user or throws Exeption. 
 * 
 * * Endpoint: POST rest/simpleconnect/login
 * 
 * {"username":yourname,"password":yourpass}
 * 
 * returns {"uid":youruid,username":yourname,"roles":[yourroles],"token":yourtoken,"session":yoursession}
 *
 */
namespace Drupal\simpleconnect\Plugin\rest\resource;
    use Drupal\Core\Session\AccountProxyInterface;
    use Drupal\node\Entity\Node;
    use Drupal\rest\ModifiedResourceResponse;
    use Drupal\rest\Plugin\ResourceBase;
    use Drupal\rest\ResourceResponse;
    use Psr\Log\LoggerInterface;
    use Symfony\Component\DependencyInjection\ContainerInterface;
    use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
    use \Drupal\Core\Url;
    use Drupal\user\Entity\User;
    use \Drupal\Core\Access\CsrfRequestHeaderAccessCheck;
    use \Drupal\Component\Utility\Html;



/**
 * Provides a resource to get view modes by entity and bundle.
 *
 * @RestResource(
 *   id = "login",
 *   label = @Translation("Login"),
 *   serialization_class = "",
 *   uri_paths = {
 *     "https://www.drupal.org/link-relations/create" = "/rest/simpleconnect/login"
 *   }
 * )
 */
class SimpleConnectLoginResource extends ResourceBase {

  protected $currentUser;
 
  /**
   * Constructs a new ExampleGetRestResource object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param array $serializer_formats
   *   The available serialization formats.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   A current user instance.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    array $serializer_formats,
    LoggerInterface $logger,
    AccountProxyInterface $current_user) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);

    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->getParameter('serializer.formats'),
      $container->get('logger.factory')->get('simpleconnect'),
      $container->get('current_user')
    );
  }

 /**
  * Responds to entity POST requests.
  * @return \Drupal\rest\ResourceResponse
  */
  public function post(array $data) {
    if($this->currentUser->isAuthenticated())return new ResourceResponse(t('This route is only accessible by anonymous users'),403);

    $name=Html::escape($data['username']);
    $pass=Html::escape($data['password']);
    if(!isset($name))return new ResourceResponse(t('Username is required'),406);
    if(!isset($pass))return new ResourceResponse(t('Password is required'),406);

    $message = [
      'uid' => 0,
      'username' => t('Anonymous'),
      'roles' => ['anonymous'],
    ];
    
    if ( $uid = \Drupal::service('user.auth')->authenticate($name,$pass)){
      $user = User::load($uid);
      //login user
      user_login_finalize($user);
      //append session and token
      $session_manager = \Drupal::service('session_manager');
      $session_id = $session_manager->getId();
      $session_name = $session_manager->getName();
      $token = \Drupal::csrfToken()->get(CsrfRequestHeaderAccessCheck::TOKEN_KEY);
      $message = [
        'uid' => $uid,
        'username' => $user->getUsername(),
        'roles' => $user->getRoles(),
        'token' => $token,
        'session' => $session_name.'_'.$session_id,
        'system' => 'DRUPAL8',
      ];
    } else return new ResourceResponse(t('Wrong username or password'),403);
    //do not cache 
    $build = array(
      '#cache' => array(
        'max-age' => 0,
      ),
    );

    return (new ResourceResponse($message,200))->addCacheableDependency($build);
      }

}

