<?php
 /**
 * Provides a REST  resource for SimpleConnect Logout Endpont.
 * Destroys session of the current user, returns anonymous user or throws an Exeption. 
 * 
 * Endpoint: POST rest/simpleconnect/logout
 * 
 * returns {"uid":0,"username":t("Anonymous"),"roles":["anonymous"]}
 *
 */
namespace Drupal\simpleconnect\Plugin\rest\resource;
use Drupal\Core\Session\AccountProxyInterface;
    use Drupal\node\Entity\Node;
    use Drupal\rest\ModifiedResourceResponse;
    use Drupal\rest\Plugin\ResourceBase;
    use Drupal\rest\ResourceResponse;
    use Psr\Log\LoggerInterface;
    use Symfony\Component\DependencyInjection\ContainerInterface;
    use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
    use Drupal\user\Entity\User;



  /**
  * Provides a resource to get view modes by entity and bundle.
  *
  * @RestResource(
  *   id = "logout",
  *   label = @Translation("Logout"),
  *   serialization_class = "",
  *   uri_paths = {
  *     "https://www.drupal.org/link-relations/create" = "/rest/simpleconnect/logout"
  *   }
  * )
  */
class SimpleConnectLogoutResource extends ResourceBase {

  protected $currentUser;
 
  /**
   * Constructs a new ExampleGetRestResource object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param array $serializer_formats
   *   The available serialization formats.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   A current user instance.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    array $serializer_formats,
    LoggerInterface $logger,
    AccountProxyInterface $current_user) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);

    $this->currentUser = $current_user;
  }


  /**
  * {@inheritdoc}
  */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->getParameter('serializer.formats'),
      $container->get('logger.factory')->get('simpleconnect'),
      $container->get('current_user')
    );
  }


 /**
 * Responds to entity GET requests.
 * @return \Drupal\rest\ResourceResponse
 */
 public function post() {
if($this->currentUser->isAnonymous())return new ResourceResponse(t("You are not logged in"),403);
$anonymous=User::getAnonymousUser();
$message = [
  'uid' => 0,
  'username' => t('Anonymous'),
  'roles' => $anonymous->getRoles()
];

//destroy sesssion if authenticated
if ($this->currentUser->isAuthenticated()) {
  $session_manager = \Drupal::service('session_manager');
  $session_manager->delete($this->currentUser->id());
  \Drupal::currentUser()->setAccount($anonymous);
}

$build = array(
  '#cache' => array(
    'max-age' => 0,
  ),
);

return (new ResourceResponse($message))->addCacheableDependency($build);
  }

}

