<?php
 /**
 * Provides a REST  resource for SimpleConnect Register Endpont.
 * Registers and returns the logged in user or throws Exeption. 
 * 
 * Endpoint: POST rest/simpleconnect/register
 * {"username":yourname,"password":yourpass,"email":youremail}
 * 
 * returns {"uid":youruid,username":yourname,"roles":[yourroles],"token":yourtoken,"session":yoursession}
 *
 */
namespace Drupal\simpleconnect\Plugin\rest\resource;
    use Drupal\Core\Session\AccountProxyInterface;
    use Drupal\node\Entity\Node;
    use Drupal\rest\ModifiedResourceResponse;
    use Drupal\rest\Plugin\ResourceBase;
    use Drupal\rest\ResourceResponse;
    use Psr\Log\LoggerInterface;
    use Symfony\Component\DependencyInjection\ContainerInterface;
    use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
    use Drupal\user\Entity\User;
    use \Drupal\Component\Utility\Html;

/**
 * Provides a User Register Resource
 *
 * @RestResource(
 *   id = "register",
 *   label = @Translation("Register"),
 *   serialization_class = "",
 *   uri_paths = {
 *     "https://www.drupal.org/link-relations/create" = "/rest/simpleconnect/register"
 *   }
 * )
 */
class SimpleConnectRegisterResource extends ResourceBase {
  protected $currentUser;
 
  /**
   * Constructs a new ExampleGetRestResource object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param array $serializer_formats
   *   The available serialization formats.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   A current user instance.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    array $serializer_formats,
    LoggerInterface $logger,
    AccountProxyInterface $current_user) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);

    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->getParameter('serializer.formats'),
      $container->get('logger.factory')->get('simpleconnect'),
      $container->get('current_user')
    );
  }
/**
   * Responds to entity GET requests.
   * @return \Drupal\rest\ResourceResponse
   */
  public function post(array $data) {
  
  if($this->currentUser->isAuthenticated())return new ResourceResponse('This route is only accessible by anonymous users',403);
 
    $name=Html::escape($data['username']);
    $pass=Html::escape($data['password']);
    $email=Html::escape($data['email']);
    
    if(!isset($email))return new ResourceResponse('Email is required',406);
    if(!isset($name))return new ResourceResponse('Username is required',406);
    if(!isset($pass))return new ResourceResponse('Password is required',406);

    $tmp_user= user_load_by_mail($email);
    if($tmp_user)return new ResourceResponse('Email already registered',406);

    $tmp_user=user_load_by_name($name);
    if($tmp_user)return new ResourceResponse('Username already exists',406);

    $language = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $user = \Drupal\user\Entity\User::create();

    //Mandatory settings
    $user->setPassword($pass);
    $user->enforceIsNew();
    $user->setEmail($email);
    $user->setUsername($name);//This username must be unique and accept 
  
    //Optional settings
    $user->set("init", $email);
    //$user->set("langcode", $language);
    //$user->set("preferred_langcode", $language);
    //$user->set("preferred_admin_langcode", $language);
    //$user->set("setting_name", 'setting_value');
    $user->activate();

  //Save user
  if(!$user->save())new ResourceResponse('Could not register new user',406);

  //Login user
  user_login_finalize($user);

  $response = [
      'uid' => $user->id(),
      'name' => $user->getUsername(),
      'roles' => $user->getRoles(),
  ];

  $build = array(
    '#cache' => array(
    'max-age' => 0,
    ),
  );

  return (new ResourceResponse($response))->addCacheableDependency($build);
  }

}

